@@ -408,11 +408,39 @@ def make_mask(X, Y, ap_center, ap_size, seeing = None):
     return mask
 
 def revert_seterr(oldsettings):
+    """
+    This function revert the options of seterr to a value saved in oldsettings.
+    
+    Usage:
+        oldsettings = np.seterr(all='ignore')
+        to_return = (result - int_ratio) / int_ratio # this will not issue Warning messages
+        revert_seterr(oldsettings)
+    Parameter:
+        oldsettings: result of np.seterr(all='ignore')
+    """
     np.seterr(over = oldsettings['over'])
     np.seterr(divide = oldsettings['divide'])
     np.seterr(invalid = oldsettings['invalid'])
     np.seterr(under = oldsettings['under'])
      
+def quiet_divide(a, b):
+    """
+    This function returns the division of a by b, without any waring in case of b beeing 0.
+    """
+    oldsettings = np.seterr(all='ignore')
+    to_return = a / b # this will not issue Warning messages
+    revert_seterr(oldsettings)
+    return to_return
+
+def quiet_log10(a):
+    """
+    This function returns the log10 of a, without any waring in case of b beeing 0.
+    """
+    oldsettings = np.seterr(all='ignore')
+    to_return = np.log10(a) # this will not issue Warning messages
+    revert_seterr(oldsettings)
+    return to_return
+     
 class ImportFromFile(object):
     """
     Create an object with parameters as defined in the file_to_import (which is a python-style file)
